==> deltaspike-1.9.6-source-release.zip: deltaspike-1.9.6/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/literal/ViewControllerRefLiteral.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.deltaspike.core.api.literal;

import org.apache.deltaspike.core.api.config.view.controller.ViewControllerRef;

import javax.enterprise.util.AnnotationLiteral;

/**
 * Literal for {@link org.apache.deltaspike.core.api.config.view.controller.ViewControllerRef}
 */
public class ViewControllerRefLiteral extends AnnotationLiteral<ViewControllerRef> implements ViewControllerRef
{
    private static final long serialVersionUID = 8582580975876369665L;

    private final Class value;
    private final String name;

    public ViewControllerRefLiteral(Class value, String name)
    {
        this.value = value;
        this.name = name;
    }

    @Override
    public Class value()
    {
        return this.value;
    }

    @Override
    public String name()
    {
        return this.name;
    }
}

==> deltaspike-2.0.1-source-release.zip: deltaspike-2.0.1/deltaspike/core/api/src/main/java/org/apache/deltaspike/core/api/literal/ViewControllerRefLiteral.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.deltaspike.core.api.literal;

import org.apache.deltaspike.core.api.config.view.controller.ViewControllerRef;

import jakarta.enterprise.util.AnnotationLiteral;

/**
 * Literal for {@link org.apache.deltaspike.core.api.config.view.controller.ViewControllerRef}
 */
public class ViewControllerRefLiteral extends AnnotationLiteral<ViewControllerRef> implements ViewControllerRef
{
    private static final long serialVersionUID = 8582580975876369665L;

    private final Class value;
    private final String name;

    public ViewControllerRefLiteral(Class value, String name)
    {
        this.value = value;
        this.name = name;
    }

    @Override
    public Class value()
    {
        return this.value;
    }

    @Override
    public String name()
    {
        return this.name;
    }
}
